# BDViz
A Visualization Tool for Brown Dwarfs in the Milky Way!

You can install the package with a pip install:

```
pip install BDviz
```


After pip installing BDViz, navigate to the BDViz folder on this repository and download the Jupyter Notebook titled 'run_examples.ipynb'. This notebook runs through a working example of code, and how to call some of the methods and helper functions for the interactive plotting tool.

[![A rectangular badge, half black half purple containing the text made at Code Astro](https://img.shields.io/badge/Made%20at-Code/Astro-blueviolet.svg)](https://semaphorep.github.io/codeastro/)
